summaryrefslogtreecommitdiff
path: root/src/xsvf
diff options
context:
space:
mode:
authorZachary T Welch <zw@superlucidity.net>2009-11-15 08:15:59 -0800
committerZachary T Welch <zw@superlucidity.net>2009-11-17 11:38:07 -0800
commit23402315ce01071f30d7ec0c5ca7563ce41f1cc6 (patch)
tree2b1cad0044d857844f7d6b35b5ffadd390594c9b /src/xsvf
parent7bf1a86e473a12882bf6f71cb4d0d416394b69d4 (diff)
downloadopenocd+libswd-23402315ce01071f30d7ec0c5ca7563ce41f1cc6.tar.gz
openocd+libswd-23402315ce01071f30d7ec0c5ca7563ce41f1cc6.tar.bz2
openocd+libswd-23402315ce01071f30d7ec0c5ca7563ce41f1cc6.tar.xz
openocd+libswd-23402315ce01071f30d7ec0c5ca7563ce41f1cc6.zip
command_handler: change 'args' to CMD_ARGV
This patch converts all instances of 'args' in COMMAND_HANDLER routines to use CMD_ARGV macro.
Diffstat (limited to 'src/xsvf')
-rw-r--r--src/xsvf/xsvf.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/xsvf/xsvf.c b/src/xsvf/xsvf.c
index 311acc60..1fe0b867 100644
--- a/src/xsvf/xsvf.c
+++ b/src/xsvf/xsvf.c
@@ -225,15 +225,15 @@ COMMAND_HANDLER(handle_xsvf_command)
return ERROR_FAIL;
}
- /* we mess with args starting point below, snapshot filename here */
- const char *filename = args[1];
+ /* we mess with CMD_ARGV starting point below, snapshot filename here */
+ const char *filename = CMD_ARGV[1];
- if (strcmp(args[0], "plain") != 0)
+ if (strcmp(CMD_ARGV[0], "plain") != 0)
{
- tap = jtag_tap_by_string(args[0]);
+ tap = jtag_tap_by_string(CMD_ARGV[0]);
if (!tap)
{
- command_print(cmd_ctx, "Tap: %s unknown", args[0]);
+ command_print(cmd_ctx, "Tap: %s unknown", CMD_ARGV[0]);
return ERROR_FAIL;
}
}
@@ -245,14 +245,14 @@ COMMAND_HANDLER(handle_xsvf_command)
}
/* if this argument is present, then interpret xruntest counts as TCK cycles rather than as usecs */
- if ((CMD_ARGC > 2) && (strcmp(args[2], "virt2") == 0))
+ if ((CMD_ARGC > 2) && (strcmp(CMD_ARGV[2], "virt2") == 0))
{
runtest_requires_tck = 1;
--CMD_ARGC;
- ++args;
+ ++CMD_ARGV;
}
- if ((CMD_ARGC > 2) && (strcmp(args[2], "quiet") == 0))
+ if ((CMD_ARGC > 2) && (strcmp(CMD_ARGV[2], "quiet") == 0))
{
verbose = 0;
}